@@ -44,6 +44,8 @@ class DataProcessor(ObtainRandomData, DataClean):
         ObtainRandomData.__init__(self)
         DataClean.__init__(self)
 
+
+
     def replace(self, data: list | dict | str | None) -> list | dict | str | None:
         if not data:
             return data
@@ -64,7 +66,7 @@ class DataProcessor(ObtainRandomData, DataClean):
 
     @classmethod
     def is_extract(cls, string: str) -> bool:
-        return bool(re.search(r'\$\{\{.*\}\}', string))
+        return bool(re.search(r'\$\{\{(?:[^{}]|\{[^{}]*\})*\}\}', string))
 
 
 __all__ = [
@@ -81,3 +83,7 @@ __all__ = [
     'DataProcessor',
     'SqlCache'
 ]
+
+if __name__ == '__main__':
+    processor = DataProcessor()
+    print(processor.is_extract('我是基于时间戳的5位随机数：${{number_time_5()|flow名称}}'))
