@@ -9,33 +9,33 @@ class EncryptionTool:
     """ 加密 """
 
     @classmethod
-    def md5_32_small(cls, **kwargs) -> str:
+    def md5_32_small(cls, string) -> str:
         """MD5_32位小写加密"""
         md5 = hashlib.md5()
-        md5.update(kwargs.get('data').encode('utf-8'))
+        md5.update(string.encode('utf-8'))
         encrypted_string = md5.hexdigest()
         return encrypted_string
 
     @classmethod
-    def md5_32_large(cls, **kwargs) -> str:
+    def md5_32_large(cls, string) -> str:
         """MD5_32位大写加密"""
         md5 = hashlib.md5()
-        md5.update(kwargs.get('data').encode('utf-8'))
+        md5.update(string.encode('utf-8'))
         encrypted_string = md5.hexdigest().upper()
         return encrypted_string
 
     @classmethod
-    def md5_16_small(cls, **kwargs) -> str:
+    def md5_16_small(cls, string) -> str:
         """MD5_16位小写加密"""
         md5 = hashlib.md5()
-        md5.update(kwargs.get('data').encode('utf-8'))
+        md5.update(string.encode('utf-8'))
         encrypted_string = md5.hexdigest()[8:-8]
         return encrypted_string
 
     @classmethod
-    def md5_16_large(cls, **kwargs) -> str:
+    def md5_16_large(cls, string) -> str:
         """MD5_16位大写加密"""
         md5 = hashlib.md5()
-        md5.update(kwargs.get('data').encode('utf-8'))
+        md5.update(string.encode('utf-8'))
         encrypted_string = md5.hexdigest().upper()[8:-8]
         return encrypted_string
