@@ -15,30 +15,21 @@ class RandomTimeData:
     faker = Faker(locale='zh_CN')
 
     @classmethod
-    def time_now_ymdhms(cls, **kwargs) -> str:
-        """当前年月日时分秒，-1是昨天，1是明天，以此类推"""
-        minute = kwargs.get('data')
-        if minute is None:
-            minute = 0
+    def time_now_ymdhms(cls, minute=0) -> str:
+        """当前年月日时分秒,参数：minute（默认0）"""
         target_time = datetime.now() + timedelta(days=int(minute))
         return target_time.strftime("%Y-%m-%d %H:%M:%S")
 
     @classmethod
-    def time_before_time(cls, **kwargs):
-        """当今日之前的日期"""
-        days = kwargs.get('data')
-        if days is None:
-            days = 1
+    def time_before_time(cls, days=1):
+        """当今日之前的日期,参数：days（默认1）"""
         yesterday = datetime.now() - timedelta(days=int(days))
         yesterday_str = yesterday.strftime('%Y-%m-%d')
         return yesterday_str
 
     @classmethod
-    def time_stamp(cls, **kwargs) -> int:
-        """几分钟后的时间戳"""
-        minute = kwargs.get('data')
-        if minute is None:
-            minute = 1
+    def time_stamp(cls, minute=1) -> int:
+        """几分钟后的时间戳, 参数：minute（默认1）"""
         return int(time.time() + 60 * int(minute)) * 1000
 
     @classmethod
@@ -48,19 +39,13 @@ class RandomTimeData:
         return localtime
 
     @classmethod
-    def get_time_for_min(cls, **kwargs) -> int:
-        """获取几分钟后的时间戳 参数：data"""
-        minute = kwargs.get('data')
-        if minute is None:
-            minute = 1
+    def get_time_for_min(cls, minute=1) -> int:
+        """获取几分钟后的时间戳 参数：minute（默认1）"""
         return int(time.time() + 60 * int(minute)) * 1000
 
     @classmethod
-    def time_next_minute(cls, **kwargs) -> str:
-        """几分钟后的年月日时分秒 参数：分钟"""
-        minute = kwargs.get('data')
-        if minute is None:
-            minute = 1
+    def time_next_minute(cls, minute=1) -> str:
+        """几分钟后的年月日时分秒 参数：分钟（默认1）"""
         future_time = datetime.now() + timedelta(minutes=int(minute))
         return future_time.strftime('%Y-%m-%d %H:%M:%S')
 
@@ -119,9 +104,8 @@ class RandomTimeData:
         return _time_after_week
 
     @classmethod
-    def time_day_reduce(cls, **kwargs) -> int:
-        """获取今日日期的数字，传参可以减N"""
-        types = kwargs.get('data')
+    def time_day_reduce(cls, types=0) -> int:
+        """获取今日日期的数字,参数：types（默认0）"""
         today = datetime.today()
         if types:
             return today.day - int(types)
@@ -129,19 +113,8 @@ class RandomTimeData:
             return today.day
 
     @classmethod
-    def time_day_plus(cls, **kwargs) -> int:
-        """获取今日日期的数字，传参可以加N"""
-        types = kwargs.get('data')
-        today = datetime.today()
-        if types:
-            return today.day + int(types)
-        else:
-            return today.day
-
-    @classmethod
-    def time_cron_time(cls, **kwargs) -> str:
-        """秒级cron表达式"""
-        time_parts = kwargs.get('data').split()
+    def time_cron_time(cls, time_parts) -> str:
+        """秒级cron表达式,参数：time_parts"""
         seconds = int(time_parts[0])
         minutes = int(time_parts[1])
         hours = int(time_parts[2])
@@ -157,13 +130,9 @@ class RandomTimeData:
         return time_str_result
 
     @classmethod
-    def time_next_minute_cron(cls, **kwargs):
-        """按周重复的cron表达式"""
-        if kwargs.get('data'):
-            minutes = int(kwargs.get('data'))
-        else:
-            minutes = 1
-        now = datetime.now() + timedelta(minutes=minutes)
+    def time_next_minute_cron(cls, minutes=1):
+        """按周重复的cron表达式,参数：minutes（默认1）"""
+        now = datetime.now() + timedelta(minutes=float(minutes))
         second = f"{now.second:02d}"  # 格式化为两位数
         minute = f"{now.minute:02d}"  # 格式化为两位数
         hour = f"{now.hour:02d}"  # 格式化为两位数
@@ -435,8 +404,8 @@ class RandomTimeData:
 
     @classmethod
     def time_random_utcnow(cls):
-        """当前UTC时间字符串（YYYY-MM-DDTHH:MM:SSZ）"""
-        return datetime.utcnow().strftime('%Y-%m-%dT%H:%M:%SZ')
+        """当前UTC时间字符串（YYYY-MM-DD HH:MM:SSZ）"""
+        return datetime.now().strftime('%Y-%m-%dT%H:%M:%SZ')
 
     @classmethod
     def time_random_utc_offset(cls):
