@@ -40,3 +40,10 @@ class TestCache(unittest.TestCase):
         value = processor.replace(str_)
         assert value == f"我是基于时间戳的5位随机数：{processor.get_cache('flow名称')}"
         return f"我是基于时间戳的5位随机数：{processor.get_cache('flow名称')}"
+
+    def test_005(self):
+        """获取公共方法中的数据"""
+        processor = DataProcessor()
+        processor.set_cache('key', '123456')
+        assert processor.get_cache('key') == '123456'
+        assert processor.replace('${{md5_32_small(${{key}})}}') == 'e10adc3949ba59abbe56e057f20f883e'
